==> union-star-center-api-0.0.17-20210615.081746-1-sources.jar: cn/com/duiba/tuia/union/star/center/api/remoteservice/domain/rsp/MobileUaInfoDTO.java <==
package cn.com.duiba.tuia.union.star.center.api.remoteservice.domain.rsp;

import cn.com.duiba.tuia.union.star.center.api.remoteservice.domain.common.page.BaseQuery;

import java.io.Serializable;
import java.util.Date;

/**
 * 设备ua信息对象
 * @Author: xingbo
 * @Date: 2021/6/1 2:46
 */
public class MobileUaInfoDTO extends BaseQuery implements Serializable {

    /** 主键id */
    private Long id;

    /** 品牌名称英文 */
    private String brandNameEn;

    /** 品牌名称中文 */
    private String brandNameCn;

    /** 应用市场唤起字段 */
    private String brandMarket;

    /** 设备型号 */
    private String phoneModel;

    /** 操作系统：android、ios */
    private String phoneOs;

    /** 操作系统最新版本号 */
    private String phoneOsVersion;

    /** 手机价位：1（0～599）、2（600～1099）、3（1100～1699）、4（1700～2699）、5（2700～4499）、6（4500+）、 */
    private Integer phonePriceLevel;

    /** 运营商定制：默认0不定制，1移动、2联通、3电信 */
    private Integer dmpIspCustom;

    /** 人群标签 */
    private String consumerTag;

    /** 首发时间如2015 */
    private Long firstShowTime;

    /** 存储额外信息：json */
    private String jsonExt;

    /** 创建时间 */
    private Date gmtCreate;

    /** 更新时间 */
    private Date gmtModified;

    /** 是否删除0否，1是 */
    private Integer isDeleted;

    /** pv */
    private Integer pv;

    /** pv当天日期 */
    private String curDate;

    /** 历史最高pv */
    private String historyPv;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBrandNameEn() {
        return brandNameEn;
    }

    public void setBrandNameEn(String brandNameEn) {
        this.brandNameEn = brandNameEn;
    }

    public String getBrandNameCn() {
        return brandNameCn;
    }

    public void setBrandNameCn(String brandNameCn) {
        this.brandNameCn = brandNameCn;
    }

    public String getBrandMarket() {
        return brandMarket;
    }

    public void setBrandMarket(String brandMarket) {
        this.brandMarket = brandMarket;
    }

    public String getPhoneModel() {
        return phoneModel;
    }

    public void setPhoneModel(String phoneModel) {
        this.phoneModel = phoneModel;
    }

    public String getPhoneOs() {
        return phoneOs;
    }

    public void setPhoneOs(String phoneOs) {
        this.phoneOs = phoneOs;
    }

    public String getPhoneOsVersion() {
        return phoneOsVersion;
    }

    public void setPhoneOsVersion(String phoneOsVersion) {
        this.phoneOsVersion = phoneOsVersion;
    }

    public Integer getPhonePriceLevel() {
        return phonePriceLevel;
    }

    public void setPhonePriceLevel(Integer phonePriceLevel) {
        this.phonePriceLevel = phonePriceLevel;
    }

    public Integer getDmpIspCustom() {
        return dmpIspCustom;
    }

    public void setDmpIspCustom(Integer dmpIspCustom) {
        this.dmpIspCustom = dmpIspCustom;
    }

    public Long getFirstShowTime() {
        return firstShowTime;
    }

    public void setFirstShowTime(Long firstShowTime) {
        this.firstShowTime = firstShowTime;
    }

    public String getHistoryPv() {
        return historyPv;
    }

    public void setHistoryPv(String historyPv) {
        this.historyPv = historyPv;
    }

    public String getJsonExt() {
        return jsonExt;
    }

    public void setJsonExt(String jsonExt) {
        this.jsonExt = jsonExt;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getPv() {
        return pv;
    }

    public void setPv(Integer pv) {
        this.pv = pv;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getConsumerTag() {
        return consumerTag;
    }

    public void setConsumerTag(String consumerTag) {
        this.consumerTag = consumerTag;
    }

    @Override
    public String toString() {
        return "DeviceUaInfoDto{" +
                "id=" + id +
                ", brandNameEn='" + brandNameEn + '\'' +
                ", brandNameCn='" + brandNameCn + '\'' +
                ", brandMarket='" + brandMarket + '\'' +
                ", phoneModel='" + phoneModel + '\'' +
                ", phoneOs='" + phoneOs + '\'' +
                ", phoneOsVersion='" + phoneOsVersion + '\'' +
                ", phonePriceLevel=" + phonePriceLevel +
                ", dmpIspCustom=" + dmpIspCustom +
                ", firstShowTime=" + firstShowTime +
                ", jsonExt='" + jsonExt + '\'' +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                ", isDeleted=" + isDeleted +
                '}';
    }
}

==> union-star-center-api-0.0.18-20210617.093952-2-sources.jar: cn/com/duiba/tuia/union/star/center/api/remoteservice/domain/rsp/MobileUaInfoDTO.java <==
package cn.com.duiba.tuia.union.star.center.api.remoteservice.domain.rsp;

import cn.com.duiba.tuia.union.star.center.api.remoteservice.domain.common.page.BaseQuery;

import java.io.Serializable;
import java.util.Date;

/**
 * 设备ua信息对象
 * @Author: xingbo
 * @Date: 2021/6/1 2:46
 */
public class MobileUaInfoDTO extends BaseQuery implements Serializable {

    /** 主键id */
    private Long id;

    /** 品牌名称英文 */
    private String brandNameEn;

    /** 品牌名称中文 */
    private String brandNameCn;

    /** 应用市场唤起字段 */
    private String brandMarket;

    /** 设备型号 */
    private String phoneModel;

    /** 操作系统：android、ios */
    private String phoneOs;

    /** 操作系统最新版本号 */
    private String phoneOsVersion;

    /** 手机价位：1（0～599）、2（600～1099）、3（1100～1699）、4（1700～2699）、5（2700～4499）、6（4500+）、 */
    private Integer phonePriceLevel;

    /** 运营商定制：默认0不定制，1移动、2联通、3电信 */
    private Integer dmpIspCustom;

    /** 人群标签 */
    private String consumerTag;

    /** 首发时间如2015 */
    private Long firstShowTime;

    /** 卡槽数量 **/
    private Integer cardSlotCount;

    /** 卡槽数量 **/
    private String sampleUa;

    /** 存储额外信息：json */
    private String jsonExt;

    /** 创建时间 */
    private Date gmtCreate;

    /** 更新时间 */
    private Date gmtModified;

    /** 是否删除0否，1是 */
    private Integer isDeleted;

    /** pv */
    private Integer pv;

    /** pv当天日期 */
    private String curDate;

    /** 历史最高pv */
    private String historyPv;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getBrandNameEn() {
        return brandNameEn;
    }

    public void setBrandNameEn(String brandNameEn) {
        this.brandNameEn = brandNameEn;
    }

    public String getBrandNameCn() {
        return brandNameCn;
    }

    public void setBrandNameCn(String brandNameCn) {
        this.brandNameCn = brandNameCn;
    }

    public String getBrandMarket() {
        return brandMarket;
    }

    public void setBrandMarket(String brandMarket) {
        this.brandMarket = brandMarket;
    }

    public String getPhoneModel() {
        return phoneModel;
    }

    public void setPhoneModel(String phoneModel) {
        this.phoneModel = phoneModel;
    }

    public String getPhoneOs() {
        return phoneOs;
    }

    public void setPhoneOs(String phoneOs) {
        this.phoneOs = phoneOs;
    }

    public String getPhoneOsVersion() {
        return phoneOsVersion;
    }

    public void setPhoneOsVersion(String phoneOsVersion) {
        this.phoneOsVersion = phoneOsVersion;
    }

    public Integer getPhonePriceLevel() {
        return phonePriceLevel;
    }

    public void setPhonePriceLevel(Integer phonePriceLevel) {
        this.phonePriceLevel = phonePriceLevel;
    }

    public Integer getDmpIspCustom() {
        return dmpIspCustom;
    }

    public void setDmpIspCustom(Integer dmpIspCustom) {
        this.dmpIspCustom = dmpIspCustom;
    }

    public Long getFirstShowTime() {
        return firstShowTime;
    }

    public void setFirstShowTime(Long firstShowTime) {
        this.firstShowTime = firstShowTime;
    }

    public String getHistoryPv() {
        return historyPv;
    }

    public void setHistoryPv(String historyPv) {
        this.historyPv = historyPv;
    }

    public String getJsonExt() {
        return jsonExt;
    }

    public void setJsonExt(String jsonExt) {
        this.jsonExt = jsonExt;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Integer isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getPv() {
        return pv;
    }

    public void setPv(Integer pv) {
        this.pv = pv;
    }

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getConsumerTag() {
        return consumerTag;
    }

    public void setConsumerTag(String consumerTag) {
        this.consumerTag = consumerTag;
    }

    public Integer getCardSlotCount() {
        return cardSlotCount;
    }

    public void setCardSlotCount(Integer cardSlotCount) {
        this.cardSlotCount = cardSlotCount;
    }

    public String getSampleUa() {
        return sampleUa;
    }

    public void setSampleUa(String sampleUa) {
        this.sampleUa = sampleUa;
    }

    @Override
    public String toString() {
        return "DeviceUaInfoDto{" +
                "id=" + id +
                ", brandNameEn='" + brandNameEn + '\'' +
                ", brandNameCn='" + brandNameCn + '\'' +
                ", brandMarket='" + brandMarket + '\'' +
                ", phoneModel='" + phoneModel + '\'' +
                ", phoneOs='" + phoneOs + '\'' +
                ", phoneOsVersion='" + phoneOsVersion + '\'' +
                ", phonePriceLevel=" + phonePriceLevel +
                ", dmpIspCustom=" + dmpIspCustom +
                ", firstShowTime=" + firstShowTime +
                ", jsonExt='" + jsonExt + '\'' +
                ", gmtCreate=" + gmtCreate +
                ", gmtModified=" + gmtModified +
                ", isDeleted=" + isDeleted +
                '}';
    }
}
